@@ -316,6 +316,9 @@ bool	Application::m_HaveGhemical = false;
 bool	Application::m_HaveGChem3D = false;
 bool	Application::m_HaveAvogadro = false;
 
+extern TypeId ReactionSeparatorType;
+extern TypeId StepCounterType;
+
 static void on_config_changed (GOConfNode *node, gchar const *key, Application *app)
 {
 	app->OnConfigChanged (node, key);
@@ -354,6 +357,8 @@ Application::Application (gcugtk::CmdContextGtk *cc):
 		AddType ("reactant", CreateReactant, ReactantType);
 		AddType ("reaction-arrow", CreateReactionArrow, ReactionArrowType);
 		AddType ("reaction-operator", NULL, ReactionOperatorType);
+		ReactionSeparatorType = AddType ("reaction-separator", NULL, ReactionSeparatorType);
+		StepCounterType = AddType ("step-counter", NULL, StepCounterType);
 		ReactionPropType = AddType ("reaction-prop", CreateReactionProp);
 		MesomerType = AddType ("mesomer", CreateMesomer);
 		AddType ("mesomery", CreateMesomery, MesomeryType);
@@ -370,23 +375,26 @@ Application::Application (gcugtk::CmdContextGtk *cc):
 		AddRule ("reactant", RuleMustBeIn, "reaction-step");
 		AddRule ("reaction-step", RuleMustBeIn, "reaction");
 		AddRule ("reaction", RuleMustContain, "reaction-arrow");
-		AddRule ("reaction-arrow", RuleMustBeIn, "reaction");
 		AddRule ("reaction-arrow", RuleMayContain, "reaction-prop");
+		AddRule ("reaction-arrow", RuleMayContain, "reaction-separator");
+		AddRule ("reaction-arrow", RuleMayContain, "step-counter");
 		AddRule ("reaction-prop", RuleMustBeIn, "reaction-arrow");
 		AddRule ("reaction-prop", RuleMayContain, "molecule");
 		AddRule ("reaction-prop", RuleMayContain, "text");
 		AddRule ("reaction-operator", RuleMustBeIn, "reaction-step");
+		AddRule ("reaction-separator", RuleMustBeIn, "reaction-arrow");
+		AddRule ("step-counter", RuleMustBeIn, "reaction-arrow");
 		AddRule ("reactant", RuleMayContain, "molecule");
 		AddRule ("reactant", RuleMayContain, "text");
-		AddRule ("mesomer", RuleMustContain, "molecule");
+		AddRule ("reactant", RuleMayContain, "mesomery");
+		AddRule ("mesomer", RuleMayContain, "molecule");
 		AddRule ("mesomer", RuleMustBeIn, "mesomery");
 		AddRule ("mesomery", RuleMustContain, "mesomer");
 		AddRule ("mesomery", RuleMustContain, "mesomery-arrow");
-		AddRule ("mesomery-arrow", RuleMustBeIn, "mesomery");
 		MechanismArrowType = AddType ("mechanism-arrow", CreateMechanismArrow);
 		MechanismStepType = AddType ("mechanism-step", CreateMechanismStep);
 		AddRule ("reaction-step", RuleMayContain, "mechanism-step");
-		AddRule ("mesomery", RuleMayContain, "mechanism-step");
+		AddRule ("mesomer", RuleMayContain, "mechanism-step");
 
 		// Create global signal ids
 		OnChangedSignal = Object::CreateNewSignalId ();
