@@ -4,11 +4,11 @@
  * Gnome Crystal
  * atomsdlg.h
  *
- * Copyright (C) 2002-2011 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2012 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -30,23 +30,42 @@
 #include "grid.h"
 #include <vector>
 
+/*!\file*/
 using namespace std;
 
 namespace gcr {
 class Document;
 class Application;
 
+/*!\class AtomsDlg gcr/atomsdlg.h
+\brief GCrystal atoms dialog class.
+
+This class wraps the dialog used to define atoms inside a crystal.
+*/
 class AtomsDlg: public gcugtk::Dialog
 {
 friend class AtomsDlgPrivate;
 public:
+/*!
+@param App the application running the dialog.
+@param pDoc the document.
+
+Creates the dialog.
+*/
 	AtomsDlg (Application *App, Document* pDoc);
+/*!
+The destructor.
+*/
 	virtual ~AtomsDlg ();
 
-	void Closed ();
+/*!
+Reloads the atoms list from the document. The list might have changed after
+simplification following symmetry detection.
+*/
 	void ReloadData ();
-
+	
 private:
+	void Closed ();
 	void PopulateRadiiMenu ();
 
 private:
@@ -54,7 +73,7 @@ private:
 	GcrGrid *m_Grid;
 	GcuPeriodic* periodic;
 	GtkToggleButton* CustomColor;
-	GtkColorButton *AtomColor;
+	GtkColorChooser *AtomColor;
 	GtkEntry *AtomR;
 	unsigned short m_nElt;
 	std::vector < Atom * > m_Atoms;
